@@ -2,10 +2,10 @@ import pytest
 from pydantic import UUID4
 
 from tktl.commands.deployments import GetDeployments, GetEndpoints
-from tktl.core.exceptions import APIClientException
 from tktl.login import logout
 
 
+@pytest.mark.skip(reason="This relies on our production system. Replace me")
 def test_get_deployment_commands(logged_in_context):
     cmd = GetDeployments()
     result = cmd.execute(
@@ -36,14 +36,13 @@ def test_get_deployment_commands(logged_in_context):
     assert len(result) == 4
 
     cmd = GetDeployments()
-    with pytest.raises(APIClientException):
-        logout()
-        cmd.execute(
-            UUID4("7c0f6f48-0220-450a-b4d2-bfc731f94cc3"),
-            None,
-            None,
-            None,
-            None,
-            None,
-            return_all=True,
-        )
+    logout()
+    assert not cmd.execute(
+        UUID4("7c0f6f48-0220-450a-b4d2-bfc731f94cc3"),
+        None,
+        None,
+        None,
+        None,
+        None,
+        return_all=True,
+    )
