@@ -1,13 +1,13 @@
+import pathlib
 import typing as t
 
-import numpy as np  # type: ignore
-import pandas as pd  # type: ignore
-from pydantic import BaseModel
+from tktl.core.exceptions import EndpointInstantiationError
 
-from .endpoints import AdvancedEndpoint, ArrowEndpoint, ProfiledEndpoint, TypedEndpoint
+from .endpoints import ArrowEndpoint, GenericEndpoint, ProfiledEndpoint, TypedEndpoint
+from .endpoints.abc import XType, YType
 
 # Enpoint types sorted by precedence
-ENDPOINT_TYPES = [ProfiledEndpoint, ArrowEndpoint, TypedEndpoint, AdvancedEndpoint]
+ENDPOINT_TYPES = [ProfiledEndpoint, ArrowEndpoint, TypedEndpoint, GenericEndpoint]
 
 
 class Tktl:
@@ -21,13 +21,21 @@ class Tktl:
     def endpoint(
         self,
         *,
-        X: t.Union[pd.Series, pd.DataFrame, np.ndarray, t.Any, BaseModel, None] = None,
-        y: t.Union[pd.Series, pd.DataFrame, np.ndarray, t.Any, BaseModel, None] = None,
+        X: t.Union[XType, str] = None,
+        y: t.Union[YType, str] = None,
         profile: t.Optional[str] = None,
         profile_columns: t.Optional[t.List[str]] = None,
+        track_inputs: t.Optional[t.List[str]] = None,
+        track_outputs: t.Optional[t.List[str]] = None,
         **kwargs,
     ):
 
+        if isinstance(X, str):
+            X = pathlib.Path(X)
+
+        if isinstance(y, str):
+            y = pathlib.Path(y)
+
         try:
             Constructor = next(
                 endpoint
@@ -35,7 +43,7 @@ class Tktl:
                 if endpoint.supported(X=X, y=y, profile=profile)
             )
         except StopIteration:
-            raise ValueError(
+            raise EndpointInstantiationError(
                 f"Arguments of type X={type(X)} y={type(y)} and profile={profile}"
                 " are not supported by any endpoint type."
             )
@@ -44,10 +52,13 @@ class Tktl:
             endpoint = Constructor(
                 name=f.__name__,
                 func=f,
+                position=len(self._endpoints),
                 X=X,
                 y=y,
                 profile_columns=profile_columns,
                 profile=profile,
+                track_inputs=track_inputs,
+                track_outputs=track_outputs,
                 **kwargs,
             )
             self._endpoints.append(endpoint)
